This folder includes all the parameter files needed for simulating a human nucleus. The parameters were optimized to reproduce experimental data, including Hi-C, DamID, and TSA-Seq.

- chr_lam_spec.txt: Chromosome-lamina interaction parameters

- chr_spec_param.txt: Chromosome-speckle interaction parameters

- chr_nuc_param.txt: Chromosome-nucleoli interaction parameters 

- ideal_param.txt: intra-chromosomal interaction parameters

- inter_param.txt: inter-chromosomal interaction parameters

- types_param.txt: interaction parameters among various compartmental types

